@@ -1,4 +1,6 @@
-from typing import TYPE_CHECKING, Any, Callable, Optional
+from typing import TYPE_CHECKING, Any, Callable, List, Optional
+
+from envium.exceptions import EnviumError
 
 if TYPE_CHECKING:
     pass
@@ -31,13 +33,18 @@ class Ctx(CtxGroup):
         super().__init__(name=name)
         self._root = self
         self._process()
+        a = 1
 
     def validate(self) -> None:
         self._validate()
 
+    @property
+    def errors(self) -> List[EnviumError]:
+        return self._errors
+
 
 def ctx_var(
-    default: Optional[VarType] = None,
+    default: Optional[Any] = None,
     default_factory: Optional[Callable] = None,
 ) -> Any:
     return CtxVar(default=default, default_factory=default_factory)
