@@ -2,6 +2,7 @@ import os
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Union
 
+from envium import comp
 from envium.exceptions import EnviumError, RedefinedVarError
 
 if TYPE_CHECKING:
@@ -39,7 +40,7 @@ class EnvVar(Var):
             env_value = None if env_value == "None" else env_value
             self._value = self._from_str(env_value) if env_value else None
 
-        if not self._value:
+        if self._value is None:
             self._value = self._default
 
     def _get_env_name(self) -> str:
@@ -47,7 +48,7 @@ class EnvVar(Var):
             ret = self._name
         else:
             ret = self._fullname
-            ret = ret.replace("_", "").replace(".", "_")
+            ret = ret.replace("_", "").replace(".", "_").replace("-", "")
 
         ret = ret.upper()
 
@@ -86,6 +87,19 @@ class EnvGroup(VarGroup[EnvVar]):
         ret = super()._fullname
         return ret
 
+    def _dump(self, path: Union[Path, str]) -> None:
+        path = Path(path)
+
+        if not path.parent.exists():
+            path.parent.mkdir(parents=True)
+
+        path.touch(exist_ok=True)
+
+        content = "\n".join(
+            [f'{key}="{value}"' for key, value in self._root._get_env_vars().items()]
+        )
+        path.write_text(content, "utf-8")
+
 
 class Environ(EnvGroup):
     def __init__(self, name: str, raw: bool = False, load: bool = False):
@@ -124,7 +138,11 @@ class Environ(EnvGroup):
         envs = {}
         for v in self._flat:
             name = v._get_env_name()
-            envs[name] = str(v._get_value())
+            value = v._get_value()
+            if isinstance(value, list):
+                envs[name] = comp.list_delimiter.join([str(v) for v in value])
+            else:
+                envs[name] = str(value)
 
         envs = {k.upper(): v for k, v in envs.items()}
 
